@@ -5,7 +5,7 @@ void lcmp (int *pop,
            int *nk,
            int *K,
            int *n,
-           int *samplesize, int *burnin, int *interval,
+           int *samplesize, int *warmup, int *interval,
            double *mu, double *kappa,
            double *sigma,  double *df,
            int *Npi,
@@ -15,7 +15,7 @@ void lcmp (int *pop,
            double *sample,
            double *ppos,
            double *lpriorm,
-           int *burnintheta,
+           int *warmuptheta,
            int *verbose
 			 );
 void MHlcmp (int *Nk, int *K,
@@ -25,7 +25,7 @@ void MHlcmp (int *Nk, int *K,
             double *sigmaproposal, 
             int *N, int *Npi, double *psample,
             double *musample, double *sigmasample,
-            int *samplesize, int *staken, int *burnin, int *interval,
+            int *samplesize, int *staken, int *warmup, int *interval,
 	    int *verbose
 			 );
 #endif /* LIKELIHOODCMP_H */
