@@ -5,15 +5,15 @@ void gcmp2 (int *pop12,
             int *pop21, 
             int *nk, 
             int *K, 
-            int *n1, 
-            int *n2, 
-            int *n0, 
+            int *n1i, 
+            int *n2i, 
+            int *n12i, 
             int *samplesize, int *warmup, int *interval,
             double *mu, double *dfmu, 
             double *sigma, double *dfsigma,
 	    double *lnlam, double *nu,
             int *Npi,
-            double *muproposal, 
+            double *lnlamproposal, 
             double *nuproposal, 
             int *N, int *maxN, 
             double *sample, 
