@@ -7,7 +7,7 @@ void gcmpvis2 (int *pop12, int *pop21,
             int *n1, 
             int *n2, 
             int *n0, 
-            int *samplesize, int *burnin, int *interval,
+            int *samplesize, int *warmup, int *interval,
             double *mu, double *dfmu, 
             double *sigma, double *dfsigma,
             double *lnlam, double *nu,
@@ -35,8 +35,8 @@ void gcmpvis2 (int *pop12, int *pop21,
             int *vsample2, 
             double *posu, 
             double *lpriorm, 
-            int *burnintheta,
-            int *burninbeta,
+            int *warmuptheta,
+            int *warmupbeta,
             int *verbose
                          );
 void MHcmpbetau (int *d1, int *d2, int *n1, int *n2, int *K,
@@ -54,7 +54,7 @@ void MHcmpbetau (int *d1, int *d2, int *n1, int *n2, int *K,
             double *lmemmuproposal, double *memnuproposal, 
             double *beta0sample, double *betatsample, double *betausample,
             double *lmemmusample, double *memnusample,
-            int *samplesize, int *staken, int *burninbeta, int *interval,
+            int *samplesize, int *staken, int *warmupbeta, int *interval,
             int *verbose
          );
 #endif /* POSTERIORCMPVIS2_H */
